==> scDblFinder_1.0.0.tar.gz: scDblFinder/inst/doc/scDblFinder.R <==
## ---- include=FALSE--------------------------------------------------------
library(BiocStyle)

## ---- eval=FALSE-----------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  BiocManager::install("scDblFinder")

## ---- eval=FALSE-----------------------------------------------------------
#  BiocManager::install("plger/scDblFinder")

## ---- eval=FALSE-----------------------------------------------------------
#  library(scDblFinder)
#  sce <- scDblFinder(sce)

## ---- eval=FALSE-----------------------------------------------------------
#  library(BiocParallel)
#  sce <- scDblFinder(sce, samples="sample_id", BPPARAM=MulticoreParam(3))
#  table(sce$scDblFinder.class)

## ----ds1, fig.cap="Accuracy of the doublet detection in the mixology10x3cl dataset (a mixture of 3 cancer cell lines). All methods perform very well.", echo=FALSE----
suppressPackageStartupMessages({
  library(ggplot2)
  library(cowplot)
  library(scDblFinder)
})
data("doubletsComparison")
datasets <- doubletsComparison
scoresNames <- c("scran.score"="scran", "scDblFinder.ratio"="scDblFinder", "DF.score"="DoubletFinder", "hybrid_score"="scds")
scores <- datasets[[1]][,intersect(names(scoresNames),colnames(datasets[[1]]))]
plotROCs(scores, factor(datasets[[1]]$demuxlet_cls, c("SNG","DBL")))

## ----ds2, fig.cap="Accuracy of the doublet detection in the mixology10x5cl dataset (a mixture of 5 cancer cell lines).", echo=FALSE----
scores <- datasets[[2]][,intersect(names(scoresNames),colnames(datasets[[2]]))]
plotROCs(scores, factor(datasets[[2]]$demuxlet_cls, c("SNG","DBL")))

## ----ds3, fig.cap="Accuracy of the doublet detection in the demuxlet control (Batch 2) dataset (GSM2560248).", echo=FALSE----
scores <- datasets[[3]][,intersect(names(scoresNames),colnames(datasets[[3]]))]
plotROCs(scores, factor(datasets[[3]]$multiplets, c("singlet","doublet")))

## ----runtime, fig.cap="Running time for each method/dataset", echo=FALSE----
rt <- data.frame( time=c(14.52, 26.36, 22.88, NA, 42.74, 250.14, 269.03, 678.81, 100.05, 
                          823.09, 999.94, 956.63), 
                  method=rep(c("scds", "scran", "scDblFinder", "DoubletFinder"),3),
                  dataset=rep(c("mixology10x3cl", "mixology10x5cl", "demuxlet"),each=4) )
ggplot(rt, aes(method, time, fill=method)) + geom_col() + 
  scale_color_manual(values=colors) + facet_wrap(~dataset, scale="free", nrow=2) + 
  coord_flip() + ylab("Wall-time, in seconds") + 
  theme(legend.position="none", axis.title.y=element_blank())

## ----sessionInfo, echo=FALSE-----------------------------------------------
sessionInfo()

==> scDblFinder_1.1.6.tar.gz: scDblFinder/inst/doc/scDblFinder.R <==
## ---- include=FALSE-----------------------------------------------------------
library(BiocStyle)

## ---- eval=FALSE--------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  BiocManager::install("scDblFinder")

## ---- eval=FALSE--------------------------------------------------------------
#  BiocManager::install("plger/scDblFinder")

## ---- eval=FALSE--------------------------------------------------------------
#  library(scDblFinder)
#  sce <- scDblFinder(sce)

## ---- eval=FALSE--------------------------------------------------------------
#  library(BiocParallel)
#  sce <- scDblFinder(sce, samples="sample_id", BPPARAM=MulticoreParam(3))
#  table(sce$scDblFinder.class)

## ----ds1, fig.cap="Accuracy of the doublet detection in the mixology10x3cl dataset (a mixture of 3 cancer cell lines). All methods perform very well.", echo=FALSE----
suppressPackageStartupMessages({
  library(ggplot2)
  library(cowplot)
  library(scDblFinder)
})
data("doubletsComparison")
datasets <- doubletsComparison
scoresNames <- c("scran.score"="scran", "scDblFinder.ratio"="scDblFinder", "DF.score"="DoubletFinder", "hybrid_score"="scds")
scores <- datasets[[1]][,intersect(names(scoresNames),colnames(datasets[[1]]))]
plotROCs(scores, factor(datasets[[1]]$demuxlet_cls, c("SNG","DBL")))

## ----ds2, fig.cap="Accuracy of the doublet detection in the mixology10x5cl dataset (a mixture of 5 cancer cell lines).", echo=FALSE----
scores <- datasets[[2]][,intersect(names(scoresNames),colnames(datasets[[2]]))]
plotROCs(scores, factor(datasets[[2]]$demuxlet_cls, c("SNG","DBL")))

## ----ds3, fig.cap="Accuracy of the doublet detection in the demuxlet control (Batch 2) dataset (GSM2560248).", echo=FALSE----
scores <- datasets[[3]][,intersect(names(scoresNames),colnames(datasets[[3]]))]
plotROCs(scores, factor(datasets[[3]]$multiplets, c("singlet","doublet")))

## ----runtime, fig.cap="Running time for each method/dataset", echo=FALSE------
rt <- data.frame( time=c(14.52, 26.36, 22.88, NA, 42.74, 250.14, 269.03, 678.81, 100.05, 
                          823.09, 999.94, 956.63), 
                  method=rep(c("scds", "scran", "scDblFinder", "DoubletFinder"),3),
                  dataset=rep(c("mixology10x3cl", "mixology10x5cl", "demuxlet"),each=4) )
ggplot(rt, aes(method, time, fill=method)) + geom_col() + 
  scale_color_manual(values=colors) + facet_wrap(~dataset, scale="free", nrow=2) + 
  coord_flip() + ylab("Wall-time, in seconds") + 
  theme(legend.position="none", axis.title.y=element_blank())

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()
